Background and motivation
*************************

Vision
======

TODO

Objective
=========

TODO

.. |---| unicode:: U+02014 .. em dash

.. _DataLad: https://datalad.org
.. _Debian: http://debian.org
